@@ -62,10 +62,12 @@ public interface ClientPrincipal {
 
     Subject getDelegateSubject();
 
+    Subject getClientSubject();
+
     byte[] getResponseTicket();
 
     byte[] getClientTicket();
 
-    void dispose();
+    boolean isSPNEGO();
 
 }
