@@ -50,10 +50,6 @@
 package com.openexchange.kerberos.impl;
 
 import javax.security.auth.Subject;
-import org.ietf.jgss.GSSCredential;
-import org.ietf.jgss.GSSException;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 import com.openexchange.kerberos.ClientPrincipal;
 import com.openexchange.kerberos.KerberosUtils;
 
@@ -64,8 +60,6 @@ import com.openexchange.kerberos.KerberosUtils;
  */
 public final class ClientPrincipalImpl implements ClientPrincipal {
 
-    private static final Logger LOG = LoggerFactory.getLogger(ClientPrincipalImpl.class);
-
     private Subject clientSubject;
     private Subject delegateSubject;
     private byte[] clientTicket;
@@ -106,6 +100,7 @@ public final class ClientPrincipalImpl implements ClientPrincipal {
         return responseTicket;
     }
 
+    @Override
     public Subject getClientSubject() {
         return clientSubject;
     }
@@ -116,24 +111,7 @@ public final class ClientPrincipalImpl implements ClientPrincipal {
     }
 
     @Override
-    public void dispose() {
-        if (null != clientSubject) {
-            for (final GSSCredential credential : clientSubject.getPrivateCredentials(GSSCredential.class)) {
-                try {
-                    credential.dispose();
-                } catch (GSSException e) {
-                    LOG.error("", e);
-                }
-            }
-        }
-        if (null != delegateSubject) {
-            for (final GSSCredential credential : delegateSubject.getPrivateCredentials(GSSCredential.class)) {
-                try {
-                    credential.dispose();
-                } catch (GSSException e) {
-                    LOG.error("", e);
-                }
-            }
-        }
+    public boolean isSPNEGO() {
+        return null != clientTicket;
     }
 }
